@@ -18,9 +18,10 @@
  */
 package org.apache.gravitino.authorization.ranger.integration.test;
 
+import static org.apache.gravitino.integration.test.container.RangerContainer.RANGER_SERVER_PORT;
+
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
-import com.google.common.collect.Lists;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
@@ -28,15 +29,16 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.stream.Collectors;
+import org.apache.gravitino.authorization.AuthorizationSecurableObject;
 import org.apache.gravitino.authorization.Privilege;
 import org.apache.gravitino.authorization.Role;
-import org.apache.gravitino.authorization.ranger.RangerAuthorizationHivePlugin;
+import org.apache.gravitino.authorization.common.RangerAuthorizationProperties;
+import org.apache.gravitino.authorization.ranger.RangerAuthorizationHDFSPlugin;
+import org.apache.gravitino.authorization.ranger.RangerAuthorizationHadoopSQLPlugin;
 import org.apache.gravitino.authorization.ranger.RangerAuthorizationPlugin;
 import org.apache.gravitino.authorization.ranger.RangerHelper;
 import org.apache.gravitino.authorization.ranger.RangerPrivileges;
-import org.apache.gravitino.authorization.ranger.RangerSecurableObject;
 import org.apache.gravitino.authorization.ranger.reference.RangerDefines;
-import org.apache.gravitino.connector.AuthorizationPropertiesMeta;
 import org.apache.gravitino.integration.test.container.ContainerSuite;
 import org.apache.gravitino.integration.test.container.HiveContainer;
 import org.apache.gravitino.integration.test.container.RangerContainer;
@@ -48,6 +50,7 @@ import org.apache.ranger.plugin.model.RangerRole;
 import org.apache.ranger.plugin.model.RangerService;
 import org.apache.ranger.plugin.util.SearchFilter;
 import org.junit.jupiter.api.Assertions;
+import org.mockito.Mockito;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -56,12 +59,12 @@ public class RangerITEnv {
   private static final Logger LOG = LoggerFactory.getLogger(RangerITEnv.class);
   protected static final String RANGER_TRINO_REPO_NAME = "trinoDev";
   private static final String RANGER_TRINO_TYPE = "trino";
-  protected static final String RANGER_HIVE_REPO_NAME = "hiveDev";
+  public static final String RANGER_HIVE_REPO_NAME = "hiveDev";
   private static final String RANGER_HIVE_TYPE = "hive";
-  protected static final String RANGER_HDFS_REPO_NAME = "hdfsDev";
+  public static final String RANGER_HDFS_REPO_NAME = "hdfsDev";
   private static final String RANGER_HDFS_TYPE = "hdfs";
-  protected static RangerClient rangerClient;
-  protected static final String HADOOP_USER_NAME = "gravitino";
+  public static RangerClient rangerClient;
+  public static final String HADOOP_USER_NAME = "gravitino";
   private static volatile boolean initRangerService = false;
   private static final ContainerSuite containerSuite = ContainerSuite.getInstance();
 
@@ -82,28 +85,61 @@ public class RangerITEnv {
   // Search filter prefix file path constants
   public static final String SEARCH_FILTER_PATH = SearchFilter.RESOURCE_PREFIX + RESOURCE_PATH;
   public static RangerAuthorizationPlugin rangerAuthHivePlugin;
+  public static RangerAuthorizationPlugin rangerAuthHDFSPlugin;
   protected static RangerHelper rangerHelper;
+  protected static RangerHelper rangerHDFSHelper;
+  public static String RANGER_ADMIN_URL = null;
 
-  public static void init() {
+  public static void init(String metalakeName, boolean allowAnyoneAccessHDFS) {
     containerSuite.startRangerContainer();
+    RANGER_ADMIN_URL =
+        String.format(
+            "http://%s:%d",
+            containerSuite.getRangerContainer().getContainerIpAddress(), RANGER_SERVER_PORT);
     rangerClient = containerSuite.getRangerContainer().rangerClient;
 
     rangerAuthHivePlugin =
-        RangerAuthorizationHivePlugin.getInstance(
+        new RangerAuthorizationHadoopSQLPlugin(
+            metalakeName,
             ImmutableMap.of(
-                AuthorizationPropertiesMeta.RANGER_ADMIN_URL,
+                RangerAuthorizationProperties.RANGER_ADMIN_URL,
                 String.format(
                     "http://%s:%d",
                     containerSuite.getRangerContainer().getContainerIpAddress(),
                     RangerContainer.RANGER_SERVER_PORT),
-                AuthorizationPropertiesMeta.RANGER_AUTH_TYPE,
+                RangerAuthorizationProperties.RANGER_AUTH_TYPE,
                 RangerContainer.authType,
-                AuthorizationPropertiesMeta.RANGER_USERNAME,
+                RangerAuthorizationProperties.RANGER_USERNAME,
                 RangerContainer.rangerUserName,
-                AuthorizationPropertiesMeta.RANGER_PASSWORD,
+                RangerAuthorizationProperties.RANGER_PASSWORD,
                 RangerContainer.rangerPassword,
-                AuthorizationPropertiesMeta.RANGER_SERVICE_NAME,
+                RangerAuthorizationProperties.RANGER_SERVICE_TYPE,
+                "HadoopSQL",
+                RangerAuthorizationProperties.RANGER_SERVICE_NAME,
                 RangerITEnv.RANGER_HIVE_REPO_NAME));
+
+    RangerAuthorizationHDFSPlugin spyRangerAuthorizationHDFSPlugin =
+        Mockito.spy(
+            new RangerAuthorizationHDFSPlugin(
+                metalakeName,
+                ImmutableMap.of(
+                    RangerAuthorizationProperties.RANGER_ADMIN_URL,
+                    String.format(
+                        "http://%s:%d",
+                        containerSuite.getRangerContainer().getContainerIpAddress(),
+                        RangerContainer.RANGER_SERVER_PORT),
+                    RangerAuthorizationProperties.RANGER_AUTH_TYPE,
+                    RangerContainer.authType,
+                    RangerAuthorizationProperties.RANGER_USERNAME,
+                    RangerContainer.rangerUserName,
+                    RangerAuthorizationProperties.RANGER_PASSWORD,
+                    RangerContainer.rangerPassword,
+                    RangerAuthorizationProperties.RANGER_SERVICE_TYPE,
+                    "HDFS",
+                    RangerAuthorizationProperties.RANGER_SERVICE_NAME,
+                    RangerITEnv.RANGER_HDFS_REPO_NAME)));
+    rangerAuthHDFSPlugin = spyRangerAuthorizationHDFSPlugin;
+
     rangerHelper =
         new RangerHelper(
             rangerClient,
@@ -112,12 +148,22 @@ public class RangerITEnv {
             rangerAuthHivePlugin.ownerMappingRule(),
             rangerAuthHivePlugin.policyResourceDefinesRule());
 
+    rangerHDFSHelper =
+        new RangerHelper(
+            rangerClient,
+            RangerContainer.rangerUserName,
+            RangerITEnv.RANGER_HDFS_REPO_NAME,
+            rangerAuthHDFSPlugin.ownerMappingRule(),
+            rangerAuthHDFSPlugin.policyResourceDefinesRule());
+
     if (!initRangerService) {
       synchronized (RangerITEnv.class) {
         // No IP address set, no impact on testing
         createRangerHdfsRepository("", true);
         createRangerHiveRepository("", true);
-        allowAnyoneAccessHDFS();
+        if (allowAnyoneAccessHDFS) {
+          allowAnyoneAccessHDFS();
+        }
         initRangerService = true;
       }
     }
@@ -132,7 +178,7 @@ public class RangerITEnv {
     }
   }
 
-  static void startHiveRangerContainer() {
+  public static void startHiveRangerContainer() {
     containerSuite.startHiveRangerContainer(
         new HashMap<>(
             ImmutableMap.of(
@@ -180,8 +226,7 @@ public class RangerITEnv {
         RANGER_HDFS_REPO_NAME,
         policyName,
         policyResourceMap,
-        Collections.singletonList(policyItem),
-        false);
+        Collections.singletonList(policyItem));
   }
 
   /**
@@ -212,14 +257,13 @@ public class RangerITEnv {
     policyItem.setAccesses(
         Arrays.asList(
             new RangerPolicy.RangerPolicyItemAccess(
-                RangerPrivileges.RangerHivePrivilege.SELECT.toString())));
+                RangerPrivileges.RangerHadoopSQLPrivilege.SELECT.toString())));
     updateOrCreateRangerPolicy(
         RANGER_HIVE_TYPE,
         RANGER_HIVE_REPO_NAME,
         policyName,
         policyResourceMap,
-        Collections.singletonList(policyItem),
-        false);
+        Collections.singletonList(policyItem));
   }
 
   public void createRangerTrinoRepository(String trinoIp) {
@@ -380,7 +424,9 @@ public class RangerITEnv {
     try {
       rangerRole =
           RangerITEnv.rangerClient.getRole(
-              role.name(), rangerAuthPlugin.rangerAdminName, RangerITEnv.RANGER_HIVE_REPO_NAME);
+              rangerHelper.generateGravitinoRoleName(role.name()),
+              rangerAuthPlugin.rangerAdminName,
+              RangerITEnv.RANGER_HIVE_REPO_NAME);
       LOG.info("rangerRole: " + rangerRole.toString());
     } catch (RangerServiceException e) {
       throw new RuntimeException(e);
@@ -426,7 +472,7 @@ public class RangerITEnv {
     role.securableObjects()
         .forEach(
             securableObject -> {
-              List<RangerSecurableObject> rangerSecurableObjects =
+              List<AuthorizationSecurableObject> rangerSecurableObjects =
                   rangerAuthPlugin.translatePrivilege(securableObject);
 
               rangerSecurableObjects.forEach(
@@ -471,7 +517,11 @@ public class RangerITEnv {
                                       .allMatch(
                                           policyItem -> {
                                             // Verify role name in Ranger policy item
-                                            return policyItem.getRoles().contains(role.name());
+                                            return policyItem
+                                                .getRoles()
+                                                .contains(
+                                                    RangerHelper.GRAVITINO_ROLE_PREFIX
+                                                        + role.name());
                                           });
                               Assertions.assertTrue(match);
                             });
@@ -515,13 +565,11 @@ public class RangerITEnv {
       String serviceName,
       String policyName,
       Map<String, RangerPolicy.RangerPolicyResource> policyResourceMap,
-      List<RangerPolicy.RangerPolicyItem> policyItems,
-      boolean labelManagedByGravitino) {
+      List<RangerPolicy.RangerPolicyItem> policyItems) {
 
     Map<String, String> resourceFilter = new HashMap<>(); // use to match the precise policy
     Map<String, String> policyFilter = new HashMap<>();
     policyFilter.put(SearchFilter.SERVICE_NAME, serviceName);
-    policyFilter.put(SearchFilter.POLICY_LABELS_PARTIAL, RangerHelper.MANAGED_BY_GRAVITINO);
     final int[] index = {0};
     policyResourceMap.forEach(
         (k, v) -> {
@@ -575,9 +623,6 @@ public class RangerITEnv {
         policy.setServiceType(type);
         policy.setService(serviceName);
         policy.setName(policyName);
-        if (labelManagedByGravitino) {
-          policy.setPolicyLabels(Lists.newArrayList(RangerHelper.MANAGED_BY_GRAVITINO));
-        }
         policy.setResources(policyResourceMap);
         policy.setPolicyItems(policyItems);
         rangerClient.createPolicy(policy);
