@@ -96,6 +96,9 @@ dependencies {
   testImplementation(project(":integration-test-common", "testArtifacts"))
   testImplementation(project(":server"))
   testImplementation(project(":server-common"))
+  testImplementation(project(":catalogs:hadoop-common")) {
+    exclude("*")
+  }
 
   testImplementation(libs.bundles.jetty)
   testImplementation(libs.bundles.jersey)
@@ -129,6 +132,16 @@ dependencies {
   testImplementation(libs.testcontainers.mysql)
   testImplementation(libs.testcontainers.localstack)
   testImplementation(libs.hadoop2.aws)
+  testImplementation(libs.hadoop3.abs)
+  testImplementation(libs.hadoop3.gcs)
+
+  // You need this to run test CatalogHiveABSIT as it required hadoop3 environment introduced by hadoop3.abs
+  // (The protocol `abfss` was first introduced in Hadoop 3.2.0), However, as the there already exists
+  // hadoop2.common in the test classpath, If we added the following dependencies directly, it will
+  // cause the conflict between hadoop2 and hadoop3, resulting test failures, so we comment the
+  // following line temporarily, if you want to run the test, please uncomment it.
+  // In the future, we may need to refactor the test to avoid the conflict.
+  // testImplementation(libs.hadoop3.common)
 
   testRuntimeOnly(libs.junit.jupiter.engine)
 }
