@@ -27,6 +27,8 @@ import org.apache.gravitino.MetadataObject;
 import org.apache.gravitino.MetadataObjects;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.authorization.SupportsRoles;
+import org.apache.gravitino.credential.Credential;
+import org.apache.gravitino.credential.SupportsCredentials;
 import org.apache.gravitino.dto.file.FilesetDTO;
 import org.apache.gravitino.exceptions.NoSuchTagException;
 import org.apache.gravitino.file.Fileset;
@@ -34,12 +36,13 @@ import org.apache.gravitino.tag.SupportsTags;
 import org.apache.gravitino.tag.Tag;
 
 /** Represents a generic fileset. */
-class GenericFileset implements Fileset, SupportsTags, SupportsRoles {
+class GenericFileset implements Fileset, SupportsTags, SupportsRoles, SupportsCredentials {
 
   private final FilesetDTO filesetDTO;
 
   private final MetadataObjectTagOperations objectTagOperations;
   private final MetadataObjectRoleOperations objectRoleOperations;
+  private final MetadataObjectCredentialOperations objectCredentialOperations;
 
   GenericFileset(FilesetDTO filesetDTO, RESTClient restClient, Namespace filesetNs) {
     this.filesetDTO = filesetDTO;
@@ -50,6 +53,8 @@ class GenericFileset implements Fileset, SupportsTags, SupportsRoles {
         new MetadataObjectTagOperations(filesetNs.level(0), filesetObject, restClient);
     this.objectRoleOperations =
         new MetadataObjectRoleOperations(filesetNs.level(0), filesetObject, restClient);
+    this.objectCredentialOperations =
+        new MetadataObjectCredentialOperations(filesetNs.level(0), filesetObject, restClient);
   }
 
   @Override
@@ -93,6 +98,11 @@ class GenericFileset implements Fileset, SupportsTags, SupportsRoles {
     return this;
   }
 
+  @Override
+  public SupportsCredentials supportsCredentials() {
+    return this;
+  }
+
   @Override
   public String[] listTags() {
     return objectTagOperations.listTags();
@@ -118,6 +128,11 @@ class GenericFileset implements Fileset, SupportsTags, SupportsRoles {
     return objectRoleOperations.listBindingRoleNames();
   }
 
+  @Override
+  public Credential[] getCredentials() {
+    return objectCredentialOperations.getCredentials();
+  }
+
   @Override
   public boolean equals(Object obj) {
     if (this == obj) {
