@@ -46,6 +46,7 @@ import org.apache.gravitino.exceptions.NoSuchTagException;
 import org.apache.gravitino.exceptions.NotFoundException;
 import org.apache.gravitino.file.Fileset;
 import org.apache.gravitino.messaging.Topic;
+import org.apache.gravitino.rel.Column;
 import org.apache.gravitino.rel.Table;
 import org.apache.gravitino.rel.types.Types;
 import org.apache.gravitino.tag.SupportsTags;
@@ -69,6 +70,8 @@ public class TestSupportTags extends TestBase {
 
   private static Table relationalTable;
 
+  private static Column genericColumn;
+
   private static Fileset genericFileset;
 
   private static Topic genericTopic;
@@ -141,6 +144,8 @@ public class TestSupportTags extends TestBase {
                 .build(),
             client.restClient());
 
+    genericColumn = relationalTable.columns()[0];
+
     genericFileset =
         new GenericFileset(
             FilesetDTO.builder()
@@ -195,6 +200,14 @@ public class TestSupportTags extends TestBase {
         MetadataObjects.of("catalog1.schema1", relationalTable.name(), MetadataObject.Type.TABLE));
   }
 
+  @Test
+  public void testListTagsForColumn() throws JsonProcessingException {
+    testListTags(
+        genericColumn.supportsTags(),
+        MetadataObjects.of(
+            "catalog1.schema1.table1", genericColumn.name(), MetadataObject.Type.COLUMN));
+  }
+
   @Test
   public void testListTagsForFileset() throws JsonProcessingException {
     testListTags(
@@ -238,6 +251,14 @@ public class TestSupportTags extends TestBase {
         MetadataObjects.of("catalog1.schema1", relationalTable.name(), MetadataObject.Type.TABLE));
   }
 
+  @Test
+  public void testListTagsInfoForColumn() throws JsonProcessingException {
+    testListTagsInfo(
+        genericColumn.supportsTags(),
+        MetadataObjects.of(
+            "catalog1.schema1.table1", genericColumn.name(), MetadataObject.Type.COLUMN));
+  }
+
   @Test
   public void testListTagsInfoForFileset() throws JsonProcessingException {
     testListTagsInfo(
@@ -281,6 +302,14 @@ public class TestSupportTags extends TestBase {
         MetadataObjects.of("catalog1.schema1", relationalTable.name(), MetadataObject.Type.TABLE));
   }
 
+  @Test
+  public void testGetTagForColumn() throws JsonProcessingException {
+    testGetTag(
+        genericColumn.supportsTags(),
+        MetadataObjects.of(
+            "catalog1.schema1.table1", genericColumn.name(), MetadataObject.Type.COLUMN));
+  }
+
   @Test
   public void testGetTagForFileset() throws JsonProcessingException {
     testGetTag(
@@ -324,6 +353,14 @@ public class TestSupportTags extends TestBase {
         MetadataObjects.of("catalog1.schema1", relationalTable.name(), MetadataObject.Type.TABLE));
   }
 
+  @Test
+  public void testAssociateTagsForColumn() throws JsonProcessingException {
+    testAssociateTags(
+        genericColumn.supportsTags(),
+        MetadataObjects.of(
+            "catalog1.schema1.table1", genericColumn.name(), MetadataObject.Type.COLUMN));
+  }
+
   @Test
   public void testAssociateTagsForFileset() throws JsonProcessingException {
     testAssociateTags(
