@@ -20,7 +20,7 @@ from typing import List, Dict
 
 from gravitino.client.gravitino_client_base import GravitinoClientBase
 from gravitino.client.gravitino_metalake import GravitinoMetalake
-from gravitino.dto.dto_converters import DTOConverters
+from gravitino.client.dto_converters import DTOConverters
 from gravitino.dto.requests.metalake_create_request import MetalakeCreateRequest
 from gravitino.dto.requests.metalake_set_request import MetalakeSetRequest
 from gravitino.dto.requests.metalake_updates_request import MetalakeUpdatesRequest
@@ -29,6 +29,7 @@ from gravitino.dto.responses.metalake_list_response import MetalakeListResponse
 from gravitino.dto.responses.metalake_response import MetalakeResponse
 from gravitino.api.metalake_change import MetalakeChange
 from gravitino.exceptions.handlers.metalake_error_handler import METALAKE_ERROR_HANDLER
+from gravitino.rest.rest_utils import encode_string
 
 logger = logging.getLogger(__name__)
 
@@ -103,7 +104,7 @@ class GravitinoAdminClient(GravitinoClientBase):
         updates_request.validate()
 
         resp = self._rest_client.put(
-            self.API_METALAKES_IDENTIFIER_PATH + name,
+            self.API_METALAKES_IDENTIFIER_PATH + encode_string(name),
             updates_request,
             error_handler=METALAKE_ERROR_HANDLER,
         )
@@ -126,7 +127,7 @@ class GravitinoAdminClient(GravitinoClientBase):
 
         params = {"force": str(force)}
         resp = self._rest_client.delete(
-            self.API_METALAKES_IDENTIFIER_PATH + name,
+            self.API_METALAKES_IDENTIFIER_PATH + encode_string(name),
             params=params,
             error_handler=METALAKE_ERROR_HANDLER,
         )
@@ -147,7 +148,7 @@ class GravitinoAdminClient(GravitinoClientBase):
         metalake_enable_request = MetalakeSetRequest(in_use=True)
         metalake_enable_request.validate()
 
-        url = self.API_METALAKES_IDENTIFIER_PATH + name
+        url = self.API_METALAKES_IDENTIFIER_PATH + encode_string(name)
         self._rest_client.patch(
             url, json=metalake_enable_request, error_handler=METALAKE_ERROR_HANDLER
         )
@@ -165,7 +166,7 @@ class GravitinoAdminClient(GravitinoClientBase):
         metalake_disable_request = MetalakeSetRequest(in_use=False)
         metalake_disable_request.validate()
 
-        url = self.API_METALAKES_IDENTIFIER_PATH + name
+        url = self.API_METALAKES_IDENTIFIER_PATH + encode_string(name)
         self._rest_client.patch(
             url, json=metalake_disable_request, error_handler=METALAKE_ERROR_HANDLER
         )
