@@ -20,7 +20,7 @@ from typing import List, Dict
 
 from gravitino.api.catalog import Catalog
 from gravitino.api.catalog_change import CatalogChange
-from gravitino.dto.dto_converters import DTOConverters
+from gravitino.client.dto_converters import DTOConverters
 from gravitino.dto.metalake_dto import MetalakeDTO
 from gravitino.dto.requests.catalog_create_request import CatalogCreateRequest
 from gravitino.dto.requests.catalog_set_request import CatalogSetRequest
@@ -30,6 +30,7 @@ from gravitino.dto.responses.catalog_response import CatalogResponse
 from gravitino.dto.responses.drop_response import DropResponse
 from gravitino.dto.responses.entity_list_response import EntityListResponse
 from gravitino.exceptions.handlers.catalog_error_handler import CATALOG_ERROR_HANDLER
+from gravitino.rest.rest_utils import encode_string
 from gravitino.utils import HTTPClient
 
 
@@ -104,7 +105,9 @@ class GravitinoMetalake(MetalakeDTO):
         Returns:
             The Catalog with specified name.
         """
-        url = self.API_METALAKES_CATALOGS_PATH.format(self.name(), name)
+        url = self.API_METALAKES_CATALOGS_PATH.format(
+            encode_string(self.name()), encode_string(name)
+        )
         response = self.rest_client.get(url, error_handler=CATALOG_ERROR_HANDLER)
         catalog_resp = CatalogResponse.from_json(response.body, infer_missing=True)
 
@@ -125,7 +128,9 @@ class GravitinoMetalake(MetalakeDTO):
         Args:
             name: The name of the catalog.
             catalog_type: The type of the catalog.
-            provider: The provider of the catalog.
+            provider: The provider of the catalog. This parameter can be None if the catalog
+            provides a managed implementation. Currently, only the model catalog supports None
+            provider. For the details, please refer to the Catalog.Type.
             comment: The comment of the catalog.
             properties: The properties of the catalog.
 
@@ -146,7 +151,7 @@ class GravitinoMetalake(MetalakeDTO):
         )
         catalog_create_request.validate()
 
-        url = f"api/metalakes/{self.name()}/catalogs"
+        url = f"api/metalakes/{encode_string(self.name())}/catalogs"
         response = self.rest_client.post(
             url, json=catalog_create_request, error_handler=CATALOG_ERROR_HANDLER
         )
@@ -175,7 +180,9 @@ class GravitinoMetalake(MetalakeDTO):
         updates_request = CatalogUpdatesRequest(reqs)
         updates_request.validate()
 
-        url = self.API_METALAKES_CATALOGS_PATH.format(self.name(), name)
+        url = self.API_METALAKES_CATALOGS_PATH.format(
+            encode_string(self.name()), encode_string(name)
+        )
         response = self.rest_client.put(
             url, json=updates_request, error_handler=CATALOG_ERROR_HANDLER
         )
@@ -197,7 +204,9 @@ class GravitinoMetalake(MetalakeDTO):
             true if the catalog is dropped successfully, false if the catalog does not exist.
         """
         params = {"force": str(force)}
-        url = self.API_METALAKES_CATALOGS_PATH.format(self.name(), name)
+        url = self.API_METALAKES_CATALOGS_PATH.format(
+            encode_string(self.name()), encode_string(name)
+        )
         response = self.rest_client.delete(
             url, params=params, error_handler=CATALOG_ERROR_HANDLER
         )
@@ -220,7 +229,9 @@ class GravitinoMetalake(MetalakeDTO):
         catalog_enable_request = CatalogSetRequest(in_use=True)
         catalog_enable_request.validate()
 
-        url = self.API_METALAKES_CATALOGS_PATH.format(self.name(), name)
+        url = self.API_METALAKES_CATALOGS_PATH.format(
+            encode_string(self.name()), encode_string(name)
+        )
         self.rest_client.patch(
             url, json=catalog_enable_request, error_handler=CATALOG_ERROR_HANDLER
         )
@@ -238,7 +249,9 @@ class GravitinoMetalake(MetalakeDTO):
         catalog_disable_request = CatalogSetRequest(in_use=False)
         catalog_disable_request.validate()
 
-        url = self.API_METALAKES_CATALOGS_PATH.format(self.name(), name)
+        url = self.API_METALAKES_CATALOGS_PATH.format(
+            encode_string(self.name()), encode_string(name)
+        )
         self.rest_client.patch(
             url, json=catalog_disable_request, error_handler=CATALOG_ERROR_HANDLER
         )
