@@ -61,6 +61,10 @@ class NoSuchFilesetException(NotFoundException):
     """Exception thrown when a file with specified name is not existed."""
 
 
+class NoSuchCredentialException(NotFoundException):
+    """Exception thrown when a credential with specified credential type is not existed."""
+
+
 class NoSuchMetalakeException(NotFoundException):
     """An exception thrown when a metalake is not found."""
 
@@ -69,6 +73,14 @@ class NoSuchCatalogException(NotFoundException):
     """An exception thrown when a catalog is not found."""
 
 
+class NoSuchModelException(NotFoundException):
+    """An exception thrown when a model is not found."""
+
+
+class NoSuchModelVersionException(NotFoundException):
+    """An exception thrown when a model version is not found."""
+
+
 class AlreadyExistsException(GravitinoRuntimeException):
     """Base exception thrown when an entity or resource already exists."""
 
@@ -85,6 +97,14 @@ class CatalogAlreadyExistsException(AlreadyExistsException):
     """An exception thrown when a resource already exists."""
 
 
+class ModelAlreadyExistsException(AlreadyExistsException):
+    """An exception thrown when a model already exists."""
+
+
+class ModelVersionAliasesAlreadyExistException(AlreadyExistsException):
+    """An exception thrown when model version with aliases already exists."""
+
+
 class NotEmptyException(GravitinoRuntimeException):
     """Base class for all exceptions thrown when a resource is not empty."""
 
@@ -135,3 +155,7 @@ class UnauthorizedException(GravitinoRuntimeException):
 
 class BadRequestException(GravitinoRuntimeException):
     """An exception thrown when the request is invalid."""
+
+
+class IllegalStateException(GravitinoRuntimeException):
+    """An exception thrown when the state is invalid."""
