@@ -19,6 +19,7 @@
 package org.apache.gravitino.catalog;
 
 import static org.apache.gravitino.Catalog.PROPERTY_IN_USE;
+import static org.apache.gravitino.Catalog.Type.FILESET;
 import static org.apache.gravitino.StringIdentifier.DUMMY_ID;
 import static org.apache.gravitino.catalog.PropertiesMetadataHelpers.validatePropertyForAlter;
 import static org.apache.gravitino.catalog.PropertiesMetadataHelpers.validatePropertyForCreate;
@@ -57,7 +58,6 @@ import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
 import javax.annotation.Nullable;
 import org.apache.commons.io.FileUtils;
-import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.tuple.Pair;
 import org.apache.gravitino.Catalog;
 import org.apache.gravitino.CatalogChange;
@@ -78,6 +78,7 @@ import org.apache.gravitino.connector.CatalogOperations;
 import org.apache.gravitino.connector.HasPropertyMetadata;
 import org.apache.gravitino.connector.PropertyEntry;
 import org.apache.gravitino.connector.SupportsSchemas;
+import org.apache.gravitino.connector.authorization.BaseAuthorization;
 import org.apache.gravitino.connector.capability.Capability;
 import org.apache.gravitino.exceptions.CatalogAlreadyExistsException;
 import org.apache.gravitino.exceptions.CatalogInUseException;
@@ -94,6 +95,7 @@ import org.apache.gravitino.messaging.TopicCatalog;
 import org.apache.gravitino.meta.AuditInfo;
 import org.apache.gravitino.meta.CatalogEntity;
 import org.apache.gravitino.meta.SchemaEntity;
+import org.apache.gravitino.model.ModelCatalog;
 import org.apache.gravitino.rel.SupportsPartitions;
 import org.apache.gravitino.rel.Table;
 import org.apache.gravitino.rel.TableCatalog;
@@ -124,6 +126,7 @@ public class CatalogManager implements CatalogDispatcher, Closeable {
 
   /** Wrapper class for a catalog instance and its class loader. */
   public static class CatalogWrapper {
+
     private BaseCatalog catalog;
     private IsolatedClassLoader classLoader;
 
@@ -132,6 +135,10 @@ public class CatalogManager implements CatalogDispatcher, Closeable {
       this.classLoader = classLoader;
     }
 
+    public BaseCatalog catalog() {
+      return catalog;
+    }
+
     public <R> R doWithSchemaOps(ThrowableFunction<SupportsSchemas, R> fn) throws Exception {
       return classLoader.withClassLoader(
           cl -> {
@@ -163,6 +170,10 @@ public class CatalogManager implements CatalogDispatcher, Closeable {
           });
     }
 
+    public <R> R doWithCredentialOps(ThrowableFunction<BaseCatalog, R> fn) throws Exception {
+      return classLoader.withClassLoader(cl -> fn.apply(catalog));
+    }
+
     public <R> R doWithTopicOps(ThrowableFunction<TopicCatalog, R> fn) throws Exception {
       return classLoader.withClassLoader(
           cl -> {
@@ -173,6 +184,16 @@ public class CatalogManager implements CatalogDispatcher, Closeable {
           });
     }
 
+    public <R> R doWithModelOps(ThrowableFunction<ModelCatalog, R> fn) throws Exception {
+      return classLoader.withClassLoader(
+          cl -> {
+            if (asModels() == null) {
+              throw new UnsupportedOperationException("Catalog does not support model operations");
+            }
+            return fn.apply(asModels());
+          });
+    }
+
     public <R> R doWithCatalogOps(ThrowableFunction<CatalogOperations, R> fn) throws Exception {
       return classLoader.withClassLoader(cl -> fn.apply(catalog.ops()));
     }
@@ -231,6 +252,10 @@ public class CatalogManager implements CatalogDispatcher, Closeable {
     private TopicCatalog asTopics() {
       return catalog.ops() instanceof TopicCatalog ? (TopicCatalog) catalog.ops() : null;
     }
+
+    private ModelCatalog asModels() {
+      return catalog.ops() instanceof ModelCatalog ? (ModelCatalog) catalog.ops() : null;
+    }
   }
 
   private final Config config;
@@ -642,32 +667,110 @@ public class CatalogManager implements CatalogDispatcher, Closeable {
             "Catalog %s is in use, please disable it first or use force option", ident);
       }
 
-      List<SchemaEntity> schemas =
-          store.list(
-              Namespace.of(ident.namespace().level(0), ident.name()),
-              SchemaEntity.class,
-              EntityType.SCHEMA);
+      Namespace schemaNamespace = Namespace.of(ident.namespace().level(0), ident.name());
+      CatalogWrapper catalogWrapper = loadCatalogAndWrap(ident);
+
+      List<SchemaEntity> schemaEntities =
+          store.list(schemaNamespace, SchemaEntity.class, EntityType.SCHEMA);
       CatalogEntity catalogEntity = store.get(ident, EntityType.CATALOG, CatalogEntity.class);
 
-      if (!schemas.isEmpty() && !force) {
-        // the Kafka catalog is special, it includes a default schema
-        if (!catalogEntity.getProvider().equals("kafka") || schemas.size() > 1) {
-          throw new NonEmptyCatalogException(
-              "Catalog %s has schemas, please drop them first or use force option", ident);
-        }
+      if (containsUserCreatedSchemas(schemaEntities, catalogEntity, catalogWrapper) && !force) {
+        throw new NonEmptyCatalogException(
+            "Catalog %s has schemas, please drop them first or use force option", ident);
       }
 
+      if (includeManagedEntities(catalogEntity)) {
+        // code reach here in two cases:
+        // 1. the catalog does not have available schemas
+        // 2. the catalog has available schemas, and force is true
+        // for case 1, the forEach block can drop them without any side effect
+        // for case 2, the forEach block will drop all managed sub-entities
+        schemaEntities.forEach(
+            schema -> {
+              try {
+                catalogWrapper.doWithSchemaOps(
+                    schemaOps -> schemaOps.dropSchema(schema.nameIdentifier(), true));
+              } catch (Exception e) {
+                LOG.warn("Failed to drop schema {}", schema.nameIdentifier());
+                throw new RuntimeException("Failed to drop schema " + schema.nameIdentifier(), e);
+              }
+            });
+      }
       catalogCache.invalidate(ident);
       return store.delete(ident, EntityType.CATALOG, true);
 
     } catch (NoSuchMetalakeException | NoSuchCatalogException ignored) {
       return false;
 
-    } catch (IOException e) {
+    } catch (GravitinoRuntimeException e) {
+      throw e;
+    } catch (Exception e) {
       throw new RuntimeException(e);
     }
   }
 
+  /**
+   * Check if the given list of schema entities contains any currently existing user-created
+   * schemas.
+   *
+   * <p>This method determines if there are valid user-created schemas by comparing the provided
+   * schema entities with the actual schemas currently existing in the external data source. It
+   * excludes:
+   *
+   * <ul>
+   *   <li>1. Automatically generated schemas (such as Kafka catalog's "default" schema or
+   *       JDBC-PostgreSQL catalog's "public" schema).
+   *   <li>2. Schemas that have been dropped externally but still exist in the entity store.
+   * </ul>
+   *
+   * @param schemaEntities The list of schema entities to check.
+   * @param catalogEntity The catalog entity to which the schemas belong.
+   * @param catalogWrapper The catalog wrapper for the catalog.
+   * @return True if the list of schema entities contains any valid user-created schemas, false
+   *     otherwise.
+   * @throws Exception If an error occurs while checking the schemas.
+   */
+  private boolean containsUserCreatedSchemas(
+      List<SchemaEntity> schemaEntities, CatalogEntity catalogEntity, CatalogWrapper catalogWrapper)
+      throws Exception {
+    if (schemaEntities.isEmpty()) {
+      return false;
+    }
+
+    if (schemaEntities.size() == 1) {
+      if ("kafka".equals(catalogEntity.getProvider())) {
+        return false;
+
+      } else if ("jdbc-postgresql".equals(catalogEntity.getProvider())) {
+        // PostgreSQL catalog includes the "public" schema, see
+        // https://github.com/apache/gravitino/issues/2314
+        return !schemaEntities.get(0).name().equals("public");
+      } else if ("hive".equals(catalogEntity.getProvider())) {
+        return !schemaEntities.get(0).name().equals("default");
+      }
+    }
+
+    NameIdentifier[] allSchemas =
+        catalogWrapper.doWithSchemaOps(
+            schemaOps ->
+                schemaOps.listSchemas(
+                    Namespace.of(catalogEntity.namespace().level(0), catalogEntity.name())));
+    if (allSchemas.length == 0) {
+      return false;
+    }
+
+    Set<String> availableSchemaNames =
+        Arrays.stream(allSchemas).map(NameIdentifier::name).collect(Collectors.toSet());
+
+    // some schemas are dropped externally, but still exist in the entity store, those schemas are
+    // invalid
+    return schemaEntities.stream().map(SchemaEntity::name).anyMatch(availableSchemaNames::contains);
+  }
+
+  private boolean includeManagedEntities(CatalogEntity catalogEntity) {
+    return catalogEntity.getType().equals(FILESET);
+  }
+
   /**
    * Loads the catalog with the specified identifier, wraps it in a CatalogWrapper, and caches the
    * wrapper for reuse.
@@ -848,7 +951,7 @@ public class CatalogManager implements CatalogDispatcher, Closeable {
       String catalogPkgPath = buildPkgPath(conf, provider);
       String catalogConfPath = buildConfPath(conf, provider);
       ArrayList<String> libAndResourcesPaths = Lists.newArrayList(catalogPkgPath, catalogConfPath);
-      buildAuthorizationPkgPath(conf).ifPresent(libAndResourcesPaths::add);
+      BaseAuthorization.buildAuthorizationPkgPath(conf).ifPresent(libAndResourcesPaths::add);
       return IsolatedClassLoader.buildClassLoader(libAndResourcesPaths);
     } else {
       // This will use the current class loader, it is mainly used for test.
@@ -965,37 +1068,6 @@ public class CatalogManager implements CatalogDispatcher, Closeable {
     return pkgPath;
   }
 
-  private Optional<String> buildAuthorizationPkgPath(Map<String, String> conf) {
-    String gravitinoHome = System.getenv("GRAVITINO_HOME");
-    Preconditions.checkArgument(gravitinoHome != null, "GRAVITINO_HOME not set");
-    boolean testEnv = System.getenv("GRAVITINO_TEST") != null;
-
-    String authorizationProvider = conf.get(Catalog.AUTHORIZATION_PROVIDER);
-    if (StringUtils.isBlank(authorizationProvider)) {
-      return Optional.empty();
-    }
-
-    String pkgPath;
-    if (testEnv) {
-      // In test, the authorization package is under the build directory.
-      pkgPath =
-          String.join(
-              File.separator,
-              gravitinoHome,
-              "authorizations",
-              "authorization-" + authorizationProvider,
-              "build",
-              "libs");
-    } else {
-      // In real environment, the authorization package is under the authorization directory.
-      pkgPath =
-          String.join(
-              File.separator, gravitinoHome, "authorizations", authorizationProvider, "libs");
-    }
-
-    return Optional.of(pkgPath);
-  }
-
   private Class<? extends CatalogProvider> lookupCatalogProvider(String provider, ClassLoader cl) {
     ServiceLoader<CatalogProvider> loader = ServiceLoader.load(CatalogProvider.class, cl);
 
