@@ -20,6 +20,8 @@ package org.apache.gravitino.utils;
 
 import com.google.errorprone.annotations.FormatMethod;
 import com.google.errorprone.annotations.FormatString;
+import org.apache.gravitino.Entity;
+import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.exceptions.IllegalNamespaceException;
 
@@ -70,6 +72,16 @@ public class NamespaceUtil {
     return Namespace.of(metalake, catalog, schema);
   }
 
+  /**
+   * Create a namespace for tag.
+   *
+   * @param metalake The metalake name
+   * @return A namespace for tag
+   */
+  public static Namespace ofTag(String metalake) {
+    return Namespace.of(metalake, Entity.SYSTEM_CATALOG_RESERVED_NAME, Entity.TAG_SCHEMA_NAME);
+  }
+
   /**
    * Create a namespace for column.
    *
@@ -107,6 +119,46 @@ public class NamespaceUtil {
     return Namespace.of(metalake, catalog, schema);
   }
 
+  /**
+   * Create a namespace for model.
+   *
+   * @param metalake The metalake name
+   * @param catalog The catalog name
+   * @param schema The schema name
+   * @return A namespace for model
+   */
+  public static Namespace ofModel(String metalake, String catalog, String schema) {
+    return Namespace.of(metalake, catalog, schema);
+  }
+
+  /**
+   * Create a namespace for model version.
+   *
+   * @param metalake The metalake name
+   * @param catalog The catalog name
+   * @param schema The schema name
+   * @param model The model name
+   * @return A namespace for model version
+   */
+  public static Namespace ofModelVersion(
+      String metalake, String catalog, String schema, String model) {
+    return Namespace.of(metalake, catalog, schema, model);
+  }
+
+  /**
+   * Convert a model name identifier to a model version namespace.
+   *
+   * @param modelIdent The model name identifier
+   * @return A model version namespace
+   */
+  public static Namespace toModelVersionNs(NameIdentifier modelIdent) {
+    return ofModelVersion(
+        modelIdent.namespace().level(0),
+        modelIdent.namespace().level(1),
+        modelIdent.namespace().level(2),
+        modelIdent.name());
+  }
+
   /**
    * Check if the given metalake namespace is legal, throw an {@link IllegalNamespaceException} if
    * it's illegal.
@@ -198,6 +250,32 @@ public class NamespaceUtil {
         namespace);
   }
 
+  /**
+   * Check if the given model namespace is legal, throw an {@link IllegalNamespaceException} if it's
+   * illegal.
+   *
+   * @param namespace The model namespace
+   */
+  public static void checkModel(Namespace namespace) {
+    check(
+        namespace != null && namespace.length() == 3,
+        "Model namespace must be non-null and have 3 levels, the input namespace is %s",
+        namespace);
+  }
+
+  /**
+   * Check if the given model version namespace is legal, throw an {@link IllegalNamespaceException}
+   * if it's illegal.
+   *
+   * @param namespace The model version namespace
+   */
+  public static void checkModelVersion(Namespace namespace) {
+    check(
+        namespace != null && namespace.length() == 4,
+        "Model version namespace must be non-null and have 4 levels, the input namespace is %s",
+        namespace);
+  }
+
   /**
    * Check the given condition is true. Throw an {@link IllegalNamespaceException} if it's not.
    *
